@@ -7,6 +7,7 @@ Tag Interface
 .. autoclass:: Taggable
 .. autoclass:: Tag
 .. autoclass:: UniqueTag
+.. autoclass:: IgnoredForEqualityTag
 
 Supporting Functionality
 ------------------------
@@ -18,9 +19,9 @@ Supporting Functionality
 Internal stuff that is only here because the documentation tool wants it
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-.. class:: TagsOfTypeT
+.. class:: TagT
 
-    A type variable used in :meth:`Taggable.tags_of_type`.
+    A type variable with lower bound :class:`Tag`.
 """
 
 import sys
@@ -166,7 +167,7 @@ class UniqueTag(Tag):
 
 
 ToTagSetConvertible = Union[Iterable[Tag], Tag, None]
-TagsOfTypeT = TypeVar("TagsOfTypeT", bound="Type[Tag]")
+TagT = TypeVar("TagT", bound="Tag")
 
 
 # {{{ UniqueTag rules checking
@@ -243,6 +244,7 @@ class Taggable:
     .. automethod:: tagged
     .. automethod:: without_tags
     .. automethod:: tags_of_type
+    .. automethod:: tags_not_of_type
 
     .. versionadded:: 2021.1
     """
@@ -313,15 +315,51 @@ class Taggable:
         return self._with_new_tags(tags=check_tag_uniqueness(new_tags))
 
     @memoize_method
-    def tags_of_type(self, tag_t: TagsOfTypeT) -> FrozenSet[TagsOfTypeT]:
+    def tags_of_type(self, tag_t: Type[TagT]) -> FrozenSet[TagT]:
         """
         Returns *self*'s tags of type *tag_t*.
         """
-        # type-ignore reason: mypy can't tell the generator has elements of
-        # type 'TagsOfTypeT' (infers it as elements of type 'Tag')
-        return frozenset(tag  # type: ignore[misc]
+        return frozenset({tag
                          for tag in self.tags
-                         if isinstance(tag, tag_t))
+                         if isinstance(tag, tag_t)})
+
+    @memoize_method
+    def tags_not_of_type(self, tag_t: Type[TagT]) -> FrozenSet[Tag]:
+        """
+        Returns *self*'s tags that are not of type *tag_t*.
+        """
+        return frozenset({tag
+                         for tag in self.tags
+                         if not isinstance(tag, tag_t)})
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, Taggable):
+            return (self.tags_not_of_type(IgnoredForEqualityTag)
+                    == other.tags_not_of_type(IgnoredForEqualityTag))
+        else:
+            return super().__eq__(other)
+
+    def __hash__(self) -> int:
+        return hash(self.tags_not_of_type(IgnoredForEqualityTag))
+
+
+# }}}
+
+
+# {{{ IgnoredForEqualityTag
+
+class IgnoredForEqualityTag(Tag):
+    """
+    A superclass for tags that are ignored when testing equality of instances of
+    :class:`Taggable`.
+
+    When testing equality of two instances of :class:`Taggable`, the equality
+    of the ``tags`` of both instances is tested after removing all
+    instances of :class:`IgnoredForEqualityTag`. Instances of
+    :class:`IgnoredForEqualityTag` are removed for hashing instances of
+    :class:`Taggable`.
+    """
+    pass
 
 # }}}
 
